#install.packages("dplyr")
library(baggr)
library(dplyr)
library(broom)

# Change this line to relevant working directory
setwd("C:/Users/Matt Lowe/Dropbox/Annual Review -- Intergroup Contact/Replication Files/data/analysis")

# Set this to 12 for the core results, 0 or 80 for the robustness
rho <- 12

results <- data.frame(
   s = integer(),
   l95 = numeric(),
   tau = numeric(),
   u95 = numeric(),
   hypersdl95 = numeric(),
   hypersdmean = numeric(),
   hypersdu95 = numeric(),
   isql95 = numeric(),
   isqmean = numeric(),
   isqu95 = numeric(),
   postpredl95 = numeric(),
   postpredl50 = numeric(),
   postpredmean = numeric(),
   postpredu50 = numeric(),
   postpredu95 = numeric()
)

lowemeta <- read.csv("4_lowe_contact_effects_explvl.csv")

for (i in 1:8) {
  
  effect_size_col <- paste0("exp_effect_size_s",i)
  se_col <- paste0("exp_se_std",rho,"_s",i)
  
  lowemeta_filtered <- lowemeta %>% select(registry_expID, !!sym(effect_size_col), !!sym(se_col))
  lowemeta_filtered <- lowemeta_filtered %>% rename(tau = effect_size_col, se = se_col)
  lowemeta_filtered <- na.omit(lowemeta_filtered)
  
  set.seed(116179)
  baggr_contact <- baggr(lowemeta_filtered, model = "rubin", pooling = "partial")
  
  #browser()
  
  new_obs <- tibble(
    s = i,
    l95 = hypermean(baggr_contact)[1],
    tau = hypermean(baggr_contact)[2],
    u95 = hypermean(baggr_contact)[3],
    hypersdl95 = hypersd(baggr_contact)[1],
    hypersdmean = hypersd(baggr_contact)[2],
    hypersdu95 = hypersd(baggr_contact)[3],
    isql95 = pooling(baggr_contact, metric = c("isq"), type = c("total"))[1],
    isqmean = pooling(baggr_contact, metric = c("isq"), type = c("total"))[2],
    isqu95 = pooling(baggr_contact, metric = c("isq"), type = c("total"))[3],
    postpredl95 = effect_draw(baggr_contact, summary = TRUE)[1],
    postpredmean = effect_draw(baggr_contact, summary = TRUE)[2],
    postpredu95 = effect_draw(baggr_contact, summary = TRUE)[3],
    postpredl50 = effect_draw(baggr_contact, summary = TRUE, interval = 0.5)[1],
    postpredu50 = effect_draw(baggr_contact, summary = TRUE, interval = 0.5)[3]
  )
  
  results <- bind_rows(results, new_obs)
}

write.csv(results, paste0("baggr_results",rho,".csv"), row.names = FALSE)

#print(baggr_contact, group = "TRUE")
#pooling(baggr_contact)
#effect_plot(baggr_contact)
#effect_draw(baggr_contact, summary = TRUE)
#my_baggr_comparison <- baggr_compare(lowemeta)
#plot(my_baggr_comparison)
#print(baggr_contact)